summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteblacklister.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteblacklister.h')
-rw-r--r--kopete/libkopete/kopeteblacklister.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kopeteblacklister.h b/kopete/libkopete/kopeteblacklister.h
index d5c946fe..a9f82157 100644
--- a/kopete/libkopete/kopeteblacklister.h
+++ b/kopete/libkopete/kopeteblacklister.h
@@ -52,10 +52,10 @@ public:
* Create an instance, and read the blacklist from disk if it exists.
* @param protocolId is the ID of the protocol owning accountId
* @param accountId is the ID of the owning Account.
* @param tqparent The TQObject tqparent for this class.
* @param name The TQObject name for this class.
*/
- BlackLister( const TQString &protocolId, const TQString &accountId, TQObject *tqparent = 0, const char *name = 0 );
+ BlackLister( const TQString &protocolId, const TQString &accountId, TQObject *parent = 0, const char *name = 0 );
~BlackLister();
/**
@@ -52,10 +52,10 @@ public:
* @param protocolId is the ID of the protocol owning accountId
* @param accountId is the ID of the owning Account.
- * @param tqparent The TQObject tqparent for this class.
+ * @param parent The TQObject parent for this class.
* @param name The TQObject name for this class.
*/